require "spec_helper"

describe Api::Filters::GreaterThan do

  describe "#build_param" do

    def build_param(field, condition)
      described_class.new(field, condition).build_param
    end

    it "parses um inteiro" do
      expect(build_param("amount", "gt(1000)")).to eq({ "amount > ?" => 1000 })
    end

    it "parses uma string" do
      expect(build_param("amount", "gt(string)")).to eq({ "amount > ?" => "string" })
    end

    it "parses uma data" do
      expect(build_param("date", "gt(2013-01-01)")).to eq({ "date > ?" => "2013-01-01" })
    end

  end

  describe ".elastic_query" do
    it { expect(described_class.new("amount", "gt(20)").elastic_query).to eq({ range: { amount: { gt: 20 } } }) }
  end


  describe ".handle?" do

    it "return true quando gt" do
      expect(described_class.handle?("gt(1000)")).to be_truthy
    end

    it "return false quando nao é um gt válido" do
      expect(described_class.handle?("bt(10,20)")).to be_falsey
    end

  end

end
